@@ -196,10 +196,11 @@ class Warrior(object):
     self.find_lat_lng()
 
   def find_lat_lng(self):
-    response = self.http_client.fetch("http://www.maxmind.com/app/mylocation", self.handle_lat_lng, user_agent="")
+    # response = self.http_client.fetch("http://www.maxmind.com/app/mylocation", self.handle_lat_lng, user_agent="")
+    pass
 
   def handle_lat_lng(self, response):
-    m = re.search(r"Latitude/Longitude</td>\s*<td[^>]*>\s*([-/.0-9]+)\s*</td>", response.body)
+    m = re.search(r"geoip-demo-results-tbodyLatitude/Longitude</td>\s*<td[^>]*>\s*([-/.0-9]+)\s*</td>", response.body)
     if m:
       self.lat_lng = m.group(1)
 
@@ -230,7 +231,7 @@ class Warrior(object):
                               os.path.join(self.warrior_hq_url, "api/update.json"),
                               method="POST",
                               headers={"Content-Type": "application/json"},
-                              user_agent=("ArchiveTeam Warrior/%s" % seesaw.__version__),
+                              user_agent=("ArchiveTeam Warrior/%s %s" % (seesaw.__version__, seesaw.runner_type)),
                               body=json.dumps({"warrior":{
                                 "warrior_id": realize(self.warrior_id),
                                 "lat_lng": self.lat_lng,
