@@ -250,7 +250,10 @@ class SeesawConnection(SocketConnection):
     self.clients.remove(self)
 
 
-def start_runner_server(project, runner, port_number=8001):
+def start_runner_server(project, runner, bind_address="", port_number=8001):
+  if bind_address=="0.0.0.0":
+    bind_address = ""
+
   SeesawConnection.project = project
   SeesawConnection.runner = runner
 
@@ -266,6 +269,7 @@ def start_runner_server(project, runner, port_number=8001):
                          ("/api/(.+)$", ApiHandler, {"runner": runner})]),
 #   flash_policy_port = 843,
 #   flash_policy_file = os.path.join(PUBLIC_PATH, "flashpolicy.xml"),
+    socket_io_address = bind_address,
     socket_io_port = port_number
   )
   SocketServer(application, auto_start=False)
